==> rustc-1.82_1.82.0+dfsg0ubuntu1.orig.tar.xz: rustc-1.82.0-src/src/tools/cargo/tests/testsuite/warn_on_failure.rs <==
//! Tests for whether or not warnings are displayed for build scripts.

use cargo_test_support::prelude::*;
use cargo_test_support::registry::Package;
use cargo_test_support::{project, str, Project};

static WARNING1: &str = "Hello! I'm a warning. :)";
static WARNING2: &str = "And one more!";

fn make_lib(lib_src: &str) {
    Package::new("bar", "0.0.1")
        .file(
            "Cargo.toml",
            r#"
                [package]
                name = "bar"
                authors = []
                version = "0.0.1"
                edition = "2015"
                build = "build.rs"
            "#,
        )
        .file(
            "build.rs",
            &format!(
                r#"
                    fn main() {{
                        use std::io::Write;
                        println!("cargo::warning={{}}", "{}");
                        println!("hidden stdout");
                        write!(&mut ::std::io::stderr(), "hidden stderr");
                        println!("cargo::warning={{}}", "{}");
                    }}
                "#,
                WARNING1, WARNING2
            ),
        )
        .file("src/lib.rs", &format!("fn f() {{ {} }}", lib_src))
        .publish();
}

fn make_upstream(main_src: &str) -> Project {
    project()
        .file(
            "Cargo.toml",
            r#"
                [package]
                name = "foo"
                version = "0.0.1"
                edition = "2015"
                authors = []

                [dependencies]
                bar = "*"
            "#,
        )
        .file("src/main.rs", &format!("fn main() {{ {} }}", main_src))
        .build()
}

#[cargo_test]
fn no_warning_on_success() {
    make_lib("");
    let upstream = make_upstream("");
    upstream
        .cargo("build")
        .with_stderr_data(str![[r#"
[UPDATING] `dummy-registry` index
[LOCKING] 2 packages to latest compatible versions
[DOWNLOADING] crates ...
[DOWNLOADED] bar v0.0.1 (registry `dummy-registry`)
[COMPILING] bar v0.0.1
[COMPILING] foo v0.0.1 ([ROOT]/foo)
[FINISHED] `dev` profile [unoptimized + debuginfo] target(s) in [ELAPSED]s

"#]])
        .run();
}

#[allow(deprecated)]
#[cargo_test]
fn no_warning_on_bin_failure() {
    make_lib("");
    let upstream = make_upstream("hi()");
    upstream
        .cargo("build")
        .with_status(101)
        .with_stdout_does_not_contain("hidden stdout")
        .with_stderr_does_not_contain("hidden stderr")
        .with_stderr_does_not_contain(&format!("[WARNING] {}", WARNING1))
        .with_stderr_does_not_contain(&format!("[WARNING] {}", WARNING2))
        .with_stderr_contains("[UPDATING] `[..]` index")
        .with_stderr_contains("[DOWNLOADED] bar v0.0.1 ([..])")
        .with_stderr_contains("[COMPILING] bar v0.0.1")
        .with_stderr_contains("[COMPILING] foo v0.0.1 ([..])")
        .run();
}

#[allow(deprecated)]
#[cargo_test]
fn warning_on_lib_failure() {
    make_lib("err()");
    let upstream = make_upstream("");
    upstream
        .cargo("build")
        .with_status(101)
        .with_stdout_does_not_contain("hidden stdout")
        .with_stderr_does_not_contain("hidden stderr")
        .with_stderr_does_not_contain("[COMPILING] foo v0.0.1 ([..])")
        .with_stderr_contains("[UPDATING] `[..]` index")
        .with_stderr_contains("[DOWNLOADED] bar v0.0.1 ([..])")
        .with_stderr_contains("[COMPILING] bar v0.0.1")
        .with_stderr_contains(&format!("[WARNING] bar@0.0.1: {}", WARNING1))
        .with_stderr_contains(&format!("[WARNING] bar@0.0.1: {}", WARNING2))
        .run();
}

==> rustc-1.83_1.83.0+dfsg0ubuntu1.orig.tar.xz: rustc-1.83.0-src/src/tools/cargo/tests/testsuite/warn_on_failure.rs <==
//! Tests for whether or not warnings are displayed for build scripts.

use cargo_test_support::prelude::*;
use cargo_test_support::registry::Package;
use cargo_test_support::{project, str, Project};

static WARNING1: &str = "Hello! I'm a warning. :)";
static WARNING2: &str = "And one more!";

fn make_lib(lib_src: &str) {
    Package::new("bar", "0.0.1")
        .file(
            "Cargo.toml",
            r#"
                [package]
                name = "bar"
                authors = []
                version = "0.0.1"
                edition = "2015"
                build = "build.rs"
            "#,
        )
        .file(
            "build.rs",
            &format!(
                r#"
                    fn main() {{
                        use std::io::Write;
                        println!("cargo::warning={{}}", "{}");
                        println!("hidden stdout");
                        write!(&mut ::std::io::stderr(), "hidden stderr");
                        println!("cargo::warning={{}}", "{}");
                    }}
                "#,
                WARNING1, WARNING2
            ),
        )
        .file("src/lib.rs", &format!("fn f() {{ {} }}", lib_src))
        .publish();
}

fn make_upstream(main_src: &str) -> Project {
    project()
        .file(
            "Cargo.toml",
            r#"
                [package]
                name = "foo"
                version = "0.0.1"
                edition = "2015"
                authors = []

                [dependencies]
                bar = "*"
            "#,
        )
        .file("src/main.rs", &format!("fn main() {{ {} }}", main_src))
        .build()
}

#[cargo_test]
fn no_warning_on_success() {
    make_lib("");
    let upstream = make_upstream("");
    upstream
        .cargo("build")
        .with_stderr_data(str![[r#"
[UPDATING] `dummy-registry` index
[LOCKING] 1 package to latest compatible version
[DOWNLOADING] crates ...
[DOWNLOADED] bar v0.0.1 (registry `dummy-registry`)
[COMPILING] bar v0.0.1
[COMPILING] foo v0.0.1 ([ROOT]/foo)
[FINISHED] `dev` profile [unoptimized + debuginfo] target(s) in [ELAPSED]s

"#]])
        .run();
}

#[expect(deprecated)]
#[cargo_test]
fn no_warning_on_bin_failure() {
    make_lib("");
    let upstream = make_upstream("hi()");
    upstream
        .cargo("build")
        .with_status(101)
        .with_stdout_does_not_contain("hidden stdout")
        .with_stderr_does_not_contain("hidden stderr")
        .with_stderr_does_not_contain(&format!("[WARNING] {}", WARNING1))
        .with_stderr_does_not_contain(&format!("[WARNING] {}", WARNING2))
        .with_stderr_contains("[UPDATING] `[..]` index")
        .with_stderr_contains("[DOWNLOADED] bar v0.0.1 ([..])")
        .with_stderr_contains("[COMPILING] bar v0.0.1")
        .with_stderr_contains("[COMPILING] foo v0.0.1 ([..])")
        .run();
}

#[expect(deprecated)]
#[cargo_test]
fn warning_on_lib_failure() {
    make_lib("err()");
    let upstream = make_upstream("");
    upstream
        .cargo("build")
        .with_status(101)
        .with_stdout_does_not_contain("hidden stdout")
        .with_stderr_does_not_contain("hidden stderr")
        .with_stderr_does_not_contain("[COMPILING] foo v0.0.1 ([..])")
        .with_stderr_contains("[UPDATING] `[..]` index")
        .with_stderr_contains("[DOWNLOADED] bar v0.0.1 ([..])")
        .with_stderr_contains("[COMPILING] bar v0.0.1")
        .with_stderr_contains(&format!("[WARNING] bar@0.0.1: {}", WARNING1))
        .with_stderr_contains(&format!("[WARNING] bar@0.0.1: {}", WARNING2))
        .run();
}
